from setuptools import setup

setup(
    name='jsvn_qa_utils_rest',
    version='1.0',
    description='rest client with allure and cerberus',
    packages=['jsvn_qa_utils_rest'],
    author_email='codejseven@gmail.com',
    zip_safe=False
)